==> haskell-xdg-desktop-entry-0.1.1.2-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-IjuOVvPDV0k4BWZNQMdabc
key:                  xdg-desktop-entry-0.1.1.2-IjuOVvPDV0k4BWZNQMdabc
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  f610aa18aedaf44600e981431db53589
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-IjuOVvPDV0k4BWZNQMdabc
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.2-E3sOV92oP3TAVpgEYMe33W
    filepath-1.4.2.2 ini-0.4.2-CBZKOLYVheCIj8Vt1iDRsk
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-desktop-entry-0.1.1.2-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-8Um9HorFH9cLG49oUsFC7a
key:                  xdg-desktop-entry-0.1.1.2-8Um9HorFH9cLG49oUsFC7a
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  79bb62bb4c7d2598a1f58bf40a24c163
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-8Um9HorFH9cLG49oUsFC7a
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.2-18J6XYSbZk74ajIe8v8koX
    filepath-1.4.2.2 ini-0.4.2-CBZKOLYVheCIj8Vt1iDRsk
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
